Learn R Programming

dispersionIndicators (version 0.1.5)

calculate_convex_indicators: Calculate the intra/inter batch dispersion indicators and their ratio on convex hulls of a single variable.

Description

Calculate the intra/inter batch dispersion indicators and their ratio on convex hulls of a single variable.

Usage

calculate_convex_indicators(hull_data_list, var_name)

Value

A data frame with the indicators values.

Arguments

hull_data_list

list of data frames of convex hulls.

var_name

name of the variable.