Learn R Programming

dispersionIndicators (version 0.1.5)

compute_intra: Computes Integrated Covariance Mahalanobis (ICM) mean distances within each batch in PCA-reduced space, using median and mean for center references.

Description

Computes Integrated Covariance Mahalanobis (ICM) mean distances within each batch in PCA-reduced space, using median and mean for center references.

Usage

compute_intra(pc_data, batch_col)

Value

A data frame with Mahalanobis distances mean for each batch.

Arguments

pc_data

PCA-reduced data frame.

batch_col

Name of the column representing batch or group.