compute_intra_batch_dispersion: Calculate the intra batch dispersion indicator on convex hulls of a single
variable
Description
Calculate the intra batch dispersion indicator on convex hulls of a single
variable
Usage
compute_intra_batch_dispersion(hull_data_shoelace_list)
Value
value of intra batch dispersion.
Arguments
- hull_data_shoelace_list
named list of convex hulls data frames with an additional column of shoelace core
values, for each batch.