Learn R Programming

dispersionIndicators (version 0.1.5)

compute_shoelace_core: Compute the shoelace core for convex hulls of a single variable

Description

Compute the shoelace core for convex hulls of a single variable

Usage

compute_shoelace_core(hull_data_list)

Value

named list of dataframes of convex hull concatenated with a column of shoelace core values, for each batch.

Arguments

hull_data_list

named list of data frames of convex hulls, for each batch.