Learn R Programming

dispersionIndicators (version 0.1.5)

plot_all_convex_hulls: Plot all convex hulls for each variable in a PDF file.

Description

Plot all convex hulls for each variable in a PDF file.

Usage

plot_all_convex_hulls(
  target_file_path,
  convex_analysis_res,
  show_points,
  mode = c("global", "batchwise")
)

Value

None. The function saves the plots to a PDF file.

Arguments

target_file_path

Path to the output PDF file.

convex_analysis_res

Result of the convex analysis containing data, convex hulls and indicators.

show_points

Boolean indicating whether to show points in the plot.

mode

Mode of the analysis, either "global" or "batchwise".