Plot all convex hulls for each variable in a PDF file.
plot_all_convex_hulls(
target_file_path,
convex_analysis_res,
show_points,
mode = c("global", "batchwise")
)None. The function saves the plots to a PDF file.
Path to the output PDF file.
Result of the convex analysis containing data, convex hulls and indicators.
Boolean indicating whether to show points in the plot.
Mode of the analysis, either "global" or "batchwise".